@@ -274,6 +274,8 @@ ld_gnu_opts = [
     "--out-implib",
     "--stack",
     "--subsystem",
+    "--library-path",
+    "--library",
     "-A",
     "-F",
     "-G",
@@ -497,7 +499,7 @@ gcc_optimization_opts = [
 ]
 
 cif_supported_opts = (
-    ["-D", "-U", "-nostdinc", "-fshort-wchar"]
+    ["-D", "-U", "-nostdinc", "-fshort-wchar", "-std"]
     + ["{}$".format(opt) for opt in gcc_optimization_opts]
     + cif_include_opts
 )
